Learn R Programming

sglr (version 0.7)

sglr-package: An R package for power and boundary calculations in pre-licensure vaccine trials using a sequential generalized likelihood ratio test

Description

This package is an implementation of the methodology of Shih, Lai, Heyse, and Chen (see reference below) for computing Generalized Likelihood Ratio test boundaries in pre-licensure vaccine studies

Arguments

Details

Package: sglr
Type: Package
Version: 0.05
Date: 2010-04-20
License: GPL (version 2 or later)
LazyLoad: yes

The package provides several functions. The function glrSearch computes boundaries for testing a given \(p_0\) versus \(p_1\) (specified as a two-dimensional vector) given a significance level \(\alpha\) and a type II error \(\beta\). The function computeBoundary computes the boundary in terms of a more understandable and usable quantity, such as the number of adverse events in a pre-licensure vaccine study for example. It takes as input a set of given boundaries for the GLR statistic. The third function is plotBoundary which also takes the same arguments as \(computeBoundary\) and produces a plot. The last two functions can make use of statistics computed previously for the problem, which can be specified as an argument; otherwise, the statistics are computed from scratch.

References

Mei-Chiung Shih, Tze Leung Lai, Joseph F. Heyse, and Jie Chen. Sequential Generalized Likelihood Ratio Tests for Vaccine Safety Evaluation (Statistics in Medicine, Volume 29, issue 26, p.2698-2708, 2010.)

Please also consult the website http://med.stanford.edu/biostatistics/ClinicalTrialMethodology/ for further developments.

Examples

Run this code
# NOT RUN {
library(sglr)
result <- glrSearch(p=c(.5, .75), alpha=0.05, beta=0.10)
## print(result)  ## large amounts of output possible!
result[1:3]
# }

Run the code above in your browser using DataLab